@@ -18,8 +18,6 @@ urlpatterns = patterns('',
                            PollVoteView.as_view(), name='poll_vote'),
                        url(r'^results/(?P<pk>\d+)$',
                            ResultsView.as_view(), name='poll_results'),
-                       url(r'^$', ListView.as_view(queryset=Poll.objects.all(),
-                                                   template_name='polls/index.html'), name='polls'),
-                       url(r'^polls/$', PollListView.as_view(), name='polls_user'),
+                       url(r'^$', PollListView.as_view(), name='polls'),
                        url(r'^admin/', include(admin.site.urls)),
                        )
