@@ -7,6 +7,7 @@ from django.forms.models import inlineformset_factory
 from django import forms
 from django.conf import settings
 from django.contrib import messages
+from django.core.paginator import Paginator, EmptyPage, PageNotAnInteger
 
 from polls.models import Choice, Poll, UserChoice, AnonymousUserChoice
 from polls.forms import PollForm, PollVoteForm
@@ -18,12 +19,36 @@ class PollListView(ListView):
     template_name = 'polls/index.html'
 
     def get_queryset(self):
+        queryset = Poll.objects.all()
+        
         if self.request.user.is_authenticated():
-            return Poll.objects.filter(user=self.request.user)
-        else:
-            return []
-
-
+            queryset = queryset.filter(user=self.request.user)
+        
+        return queryset
+    
+    def get_context_data(self, *args, **kwargs):
+        context = super(PollListView, self).get_context_data(*args, **kwargs)
+        
+        page_count = getattr(
+                settings,
+                'POLL_PAGE_COUNT',
+                5)
+                
+        paginator = Paginator(self.get_queryset(), page_count)
+        
+        page = self.request.GET.get('page')        
+        
+        try:
+            polls = paginator.page(page)
+        except PageNotAnInteger:
+            polls = paginator.page(1)
+        except EmptyPage:
+            polls = paginator.page(paginator.num_pages)
+        
+        context['object_list'] = polls
+        
+        return context
+        
 class ResultsView(DetailView):
     model = Poll
     template_name = 'polls/results.html'
@@ -125,13 +150,10 @@ class PollVoteView(FormView):
                 settings,
                 'POLL_MESSAGE_VOTE_ERROR_CHOICE_SELECTION',
                 'Select a choice!')
-                
+            
             messages.add_message(request, messages.WARNING, message)
             
-            if request.is_ajax():
-                return HttpResponse()
-            else:
-                return HttpResponseRedirect(request.path)
+            return HttpResponseRedirect(request.path)
 
     def get_context_data(self, *args, **kwargs):
         context = super(PollVoteView, self).get_context_data(*args, **kwargs)
@@ -144,20 +166,6 @@ class PollVoteView(FormView):
         context['form'] = self.form
         context['instance'] = instance
         
-        message = getattr(
-                settings,
-                'POLL_MESSAGE_VOTE_ERROR_CHOICE_SELECTION',
-                'Select a choice!')
-        
-        context['message1'] = message
-        
-        message = getattr(
-                settings,
-                'POLL_MESSAGE_VOTE_ERROR_ALREADY_VOTED',
-                'You have already voted in this poll!')
-        
-        context['message2'] = message
-        
         return context
 
 
